using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.IO;

namespace tryexcept.imageMetadataExample
{
    class Program
    {

        static void readMetadata(string filename)
        {
            BitmapSource img = BitmapFrame.Create(new Uri(filename));

            /* Image data */
            double mpixel = (img.PixelHeight * img.PixelWidth)/(double)1000000;
            Console.WriteLine("  Pixelsize {0}x{1} ({2} megapixels)", img.PixelWidth, img.PixelHeight,mpixel);
            Console.WriteLine("  DPI {0}x{1}", img.DpiX, img.DpiY);

            /* Image metadata */
            BitmapMetadata meta = (BitmapMetadata)img.Metadata;
            Console.WriteLine("  metadata\n    Type: {0}",meta.GetType());
            Console.WriteLine("  Title: {0}", meta.Title);
            Console.WriteLine("  Subject: {0}", meta.Subject);
            Console.WriteLine("  Comment: {0}", meta.Comment);
            Console.WriteLine("  Date taken: {0}", meta.DateTaken);
            Console.WriteLine("  Camera: {0} {1}",meta.CameraManufacturer,meta.CameraModel);
            Console.WriteLine("  Copyright: {0}", meta.Copyright);

            StringBuilder authors = new StringBuilder();
            if (meta.Author != null)
            {
                foreach (string author in meta.Author)
                {
                    authors.Append(author + "; ");
                }
                Console.WriteLine("  Author(s): {0}", authors.ToString());
            }


            Console.WriteLine("  Rating: {0}", meta.Rating);

            StringBuilder keyWords = new StringBuilder();
            if (meta.Keywords!=null) {
                foreach (string keyword in meta.Keywords) {
                    keyWords.Append(keyword+"; ");
                }
                Console.WriteLine("  Keywords: {0}", keyWords.ToString());
            }
            Console.WriteLine("");
        }


        static void Main(string[] args)
        {
            Console.WriteLine("Tryexcept.com Image metadata example");

            /* Get info from all files in c:\pictures */
            DirectoryInfo di = new DirectoryInfo(@"c:\pictures");

            /* Only JPEG files */
            FileInfo[] files = di.GetFiles("*.jpg");
            foreach (FileInfo fi in files)
            {
                Console.WriteLine(fi.Name);
                Program.readMetadata(fi.FullName);
            }

            Console.ReadLine();

        }
    }
}
